<?php

namespace App\Controller;

use App\Data\SettingsData;
use App\Service\SettingsDataService;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;

class BaseController extends AbstractController
{
    /**
     * @var SettingsData
     */
    protected $settingsData;

    /**
     * BaseController constructor.
     *
     * @param SettingsDataService $settingsDataServiceService
     */
    public function __construct(SettingsDataService $settingsDataServiceService)
    {
        $this->settingsData = $settingsDataServiceService->getData();
    }

    /**
     * Returns a rendered view.
     *
     * @param string $view
     * @param array  $parameters
     *
     * @return string
     * @throws \Twig\Error\LoaderError
     * @throws \Twig\Error\RuntimeError
     * @throws \Twig\Error\SyntaxError
     */
    protected function renderView(string $view, array $parameters = []): string
    {
        if (!$this->container->has('twig')) {
            throw new \LogicException(
                'You can not use the "renderView" method if the Twig Bundle is not available. Try running "composer require symfony/twig-bundle".'
            );
        }

        $theme = $this->settingsData->getAppTheme();
        $view = $theme.'/'.$view;

        return $this->container->get('twig')->render($view, $parameters);
    }
}
