<?php

namespace App\Form;

use App\Entity\Person;
use App\Entity\SearchLog;
use App\Entity\User;
use App\Repository\SearchLogRepository;
use App\Utility\SearchUtility;
use App\Utility\UserUtility;
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\ChoiceType;
use Symfony\Component\Form\Extension\Core\Type\DateType;
use Symfony\Component\Form\Extension\Core\Type\SubmitType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;
use Symfony\Component\Security\Core\Security;

class SearchLogsFiltersType extends AbstractType
{

    /**
     * @var EntityManagerInterface
     */
    private $entityManager;

    /**
     * @var Security
     */
    private $security;

    /**
     * SearchLogsFiltersType constructor.
     *
     * @param EntityManagerInterface $entityManager
     * @param Security               $security
     */
    public function __construct(EntityManagerInterface $entityManager, Security $security)
    {
        $this->entityManager = $entityManager;
        $this->security = $security;
    }

    /**
     * @param FormBuilderInterface $builder
     * @param array                $options
     *
     */
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $builder
            ->add(
                'responseType',
                ChoiceType::class,
                [
                    'label'       => 'searchLogsFilter.responseType',
                    'required'    => false,
                    'choices'     => SearchUtility::getResponseTypesChoices(),
                    'placeholder' => 'responseType.empty',
                ]
            )->add(
                'useName',
                ChoiceType::class,
                [
                    'label'       => 'searchLogsFilter.useName',
                    'choices'     => $this->fillUseNameChoices(),
                    'required'    => false,
                    'placeholder' => 'searchLogsFilter.useNamePlaceholder',
                ]
            )->add(
                'startDate',
                DateType::class,
                [
                    'label'    => 'searchLogsFilter.startDate',
                    'required' => false,
                    'widget'   => 'single_text',
                ]
            )->add(
                'endDate',
                DateType::class,
                [
                    'label'    => 'searchLogsFilter.endDate',
                    'required' => false,
                    'widget'   => 'single_text',
                ]
            )->add(
                'send',
                SubmitType::class,
                [
                    'label' => 'searchLogsFilter.send',
                ]
            );

        if ($this->security->isGranted(UserUtility::ROLE_AGENT)) {
            $builder->add(
                'user',
                EntityType::class,
                [
                    'label'        => 'searchLogsFilter.user',
                    'required'     => false,
                    'class'        => User::class,
                    'choice_label' => 'username',
                    'placeholder'  => 'searchLogsFilter.userPlaceholder',
                ]
            );
        }
    }

    /**
     * @param OptionsResolver $resolver
     */
    public function configureOptions(OptionsResolver $resolver)
    {
    }

    /**
     * @return array
     */
    private function fillUseNameChoices(): array
    {
        /** @var SearchLogRepository $searchLogRepository */
        $searchLogRepository = $this->entityManager->getRepository(SearchLog::class);
        /** @var User $user */
        $user = $this->security->getUser();

        $currentUser = null;

        if (!$this->security->isGranted(UserUtility::ROLE_AGENT)) {
            $currentUser = $user;
        }

        $persons = $searchLogRepository->findPersonsInSearchLogs($currentUser);

        $useNames = [];

        /** @var Person $person */
        foreach ($persons as $person) {
            $useNames[$person->getUseName()] = $person->getUseName();
        }

        return $useNames;
    }
}
