<?php

namespace App\Form;

use App\Data\SettingsData;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\CheckboxType;
use Symfony\Component\Form\Extension\Core\Type\ChoiceType;
use Symfony\Component\Form\Extension\Core\Type\FileType;
use Symfony\Component\Form\Extension\Core\Type\IntegerType;
use Symfony\Component\Form\Extension\Core\Type\TextareaType;
use Symfony\Component\Form\Extension\Core\Type\TextType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;

class SettingsType extends AbstractType
{

    /**
     * @param \Symfony\Component\Form\FormBuilderInterface $builder
     * @param array                                        $options
     *
     * @throws \Doctrine\Common\Annotations\AnnotationException
     * @throws \ReflectionException
     */
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $builder
            ->add(
                'appName',
                TextType::class,
                [
                    'required' => true,
                    'label'    => 'settings.appName',
                ]
            )
            ->add(
                'appUrl',
                TextType::class,
                [
                    'required' => false,
                    'label'    => 'settings.appUrl',
                ]
            )
            ->add(
                'appLogo',
                FileType::class,
                [
                    'required' => false,
                    'label'    => 'settings.appLogo',
                ]
            )
            ->add(
                'appFavicon',
                FileType::class,
                [
                    'required' => false,
                    'label'    => 'settings.appFavicon',
                ]
            )
            ->add(
                'appTheme',
                ChoiceType::class,
                [
                    'choices'  => [
                        'theme.default' => 'default',
                    ],
                    'required' => true,
                    'label'    => 'settings.appTheme',
                ]
            )
            ->add(
                'departmentName',
                TextType::class,
                [
                    'required' => false,
                    'label'    => 'settings.departmentName',
                ]
            )
            ->add(
                'departmentSite',
                TextType::class,
                [
                    'required' => false,
                    'label'    => 'settings.departmentSite',
                ]
            )
            ->add(
                'departmentSilSite',
                TextType::class,
                [
                    'required' => false,
                    'label'    => 'settings.departmentSilSite',
                ]
            )
            ->add(
                'soundexSearch',
                CheckboxType::class,
                [
                    'required' => false,
                    'label'    => 'settings.soundexSearch',
                ]
            )
            ->add(
                'connectionAttempts',
                IntegerType::class,
                [
                    'required' => false,
                    'label'    => 'settings.connectionAttempts',
                    'attr'     => ['min' => 0, 'max' => 10],
                ]
            )
            ->add(
                'mailSignature',
                TextareaType::class,
                [
                    'required' => false,
                    'label'    => 'settings.mailSignature',
                ]
            )
            ->add(
                'mailIntroduction',
                TextareaType::class,
                [
                    'required' => false,
                    'label'    => 'settings.mailIntroduction',
                ]
            )
            ->add(
                'mailNotaBene',
                TextareaType::class,
                [
                    'required' => false,
                    'label'    => 'settings.mailNotaBene',
                ]
            )
            ->add(
                'pdfDestinationCity',
                TextareaType::class,
                [
                    'required' => false,
                    'label'    => 'settings.pdfDestinationCity',
                ]
            )
            ->add(
                'pdfLogo1',
                FileType::class,
                [
                    'required' => false,
                    'label'    => 'settings.pdfLogo1',
                ]
            )
            ->add(
                'pdfLogo2',
                FileType::class,
                [
                    'required' => false,
                    'label'    => 'settings.pdfLogo2',
                ]
            )
            ->add(
                'pdfServiceLogo',
                FileType::class,
                [
                    'required' => false,
                    'label'    => 'settings.pdfServiceLogo',
                ]
            )
            ->add(
                'pdfSignature',
                FileType::class,
                [
                    'required' => false,
                    'label'    => 'settings.pdfSignature',
                ]
            )
            ->add(
                'pdfSuccessionMail',
                TextType::class,
                [
                    'required' => false,
                    'label'    => 'settings.pdfSuccessionMail',
                ]
            )
            ->add(
                'pdfDepartmentalHouseName',
                TextType::class,
                [
                    'required' => false,
                    'label'    => 'settings.pdfDepartmentalHouseName',
                ]
            )
            ->add(
                'pdfDepartmentalHousePhone',
                TextType::class,
                [
                    'required' => false,
                    'label'    => 'settings.pdfDepartmentalHousePhone',
                ]
            )
            ->add(
                'pdfCSS',
                FileType::class,
                [
                    'required' => false,
                    'label'    => 'settings.pdfCSS',
                ]
            );
    }

    public function configureOptions(OptionsResolver $resolver)
    {
        $resolver->setDefaults(
            [
                'data_class' => SettingsData::class,
            ]
        );
    }
}
