<?php

namespace App\Repository;

use App\Entity\SearchLog;
use App\Entity\User;
use Doctrine\Bundle\DoctrineBundle\Repository\ServiceEntityRepository;
use Doctrine\Common\Persistence\ManagerRegistry;

/**
 * @method SearchLog|null find($id, $lockMode = null, $lockVersion = null)
 * @method SearchLog|null findOneBy(array $criteria, array $orderBy = null)
 * @method SearchLog[]    findAll()
 * @method SearchLog[]    findBy(array $criteria, array $orderBy = null, $limit = null, $offset = null)
 */
class SearchLogRepository extends ServiceEntityRepository
{
    public function __construct(ManagerRegistry $registry)
    {
        parent::__construct($registry, SearchLog::class);
    }

    public function findPersonsInSearchLogs(?User $user)
    {
        $queryBuilder = $this->createQueryBuilder('s')
            ->groupBy('s.useName')
            ->orderBy('s.useName', 'ASC');

        if ($user) {
            $queryBuilder->andWhere('s.user = :user')
                ->setParameter(':user', $user);
        }

        return $queryBuilder->getQuery()->getResult();
    }

    public function findByFilter(array $filterData, ?User $user)
    {
        $queryBuilder = $this->createQueryBuilder('s');

        if (!$user && array_key_exists('user', $filterData) && $filterData['user'] instanceof User) {
            $user = $filterData['user'];
        }

        if ($user) {
            $queryBuilder->andWhere('s.user = :user')
                ->setParameter(':user', $user);
        }

        if ($filterData['responseType']) {
            $queryBuilder->andWhere('s.responseType = :responseType')
                ->setParameter('responseType', $filterData['responseType']);
        }

        if ($filterData['useName']) {
            $queryBuilder->andWhere('s.useName = :useName')
                ->setParameter('useName', $filterData['useName']);
        }

        if ($filterData['startDate'] instanceof \DateTime) {
            $queryBuilder->andWhere('s.searchDate >= :startDate')
                ->setParameter('startDate', $filterData['startDate']);
        }

        if ($filterData['endDate'] instanceof \DateTime) {
            $queryBuilder->andWhere('s.searchDate <= :endDate')
                ->setParameter('endDate', $filterData['endDate']);
        }

        return $queryBuilder->getQuery()->getResult();
    }

    /**
     * @param \DateTime $dateFrom
     * @param \DateTime $dataTo
     *
     * @return mixed
     */
    public function findSearchStats(\DateTime $dateFrom, \DateTime $dataTo)
    {
        return $this->createQueryBuilder('s')
            ->select("DATE_FORMAT(s.searchDate, '%Y-%m') as month", "s.responseType", "COUNT(s.responseType) as nb")
            ->andWhere('s.searchDate >= :dateFrom')
            ->andWhere('s.searchDate <= :dateTo')
            ->groupBy('month', 's.responseType')
            ->orderBy('month', 'DESC')
            ->orderBy('s.responseType', 'ASC')
            ->setParameters(
                [
                    'dateFrom' => $dateFrom,
                    'dateTo'   => $dataTo,
                ]
            )
            ->getQuery()
            ->getResult();
    }
}
