<?php

namespace App\Utility;

use App\Repository\UserRepository;
use Rollerworks\Component\PasswordStrength\Validator\Constraints\PasswordRequirements;
use Symfony\Component\Validator\Validator\ValidatorInterface;
use Symfony\Contracts\Translation\TranslatorInterface;
use Symfony\Component\Console\Exception\InvalidArgumentException;

class Validator
{
    private $translator;
    private $userRepository;
    private $validator;

    public function __construct(
        TranslatorInterface $translator,
        UserRepository $userRepository,
        ValidatorInterface $validator
    ) {
        $this->translator = $translator;
        $this->userRepository = $userRepository;
        $this->validator = $validator;
    }


    public function validateUsername(?string $username): string
    {
        if (empty($username)) {
            throw new InvalidArgumentException($this->translator->trans('addUser.error.notEmpty'));
        }

        $user = $this->userRepository->findOneBy(['username' => $username]);

        if ($user) {
            throw new InvalidArgumentException(
                $this->translator->trans('addUser.error.userUsernameExists', ['%username%' => $username])
            );
        }

        return $username;
    }

    public function validateEmail(?string $email): string
    {
        if (empty($email)) {
            throw new InvalidArgumentException($this->translator->trans('addUser.error.notEmpty'));
        }

        $userEmail = $this->userRepository->findOneBy(['email' => $email]);

        if ($userEmail) {
            throw new InvalidArgumentException(
                $this->translator->trans('addUser.error.userEmailExists', ['%email%' => $email])
            );
        }

        return $email;
    }

    public function validatePassword(?string $plainPassword): string
    {
        if (empty($plainPassword)) {
            throw new InvalidArgumentException($this->translator->trans('addUser.error.notEmpty'));
        }

        $passwordConstraint = new PasswordRequirements(
            [
                'minLength'               => 12,
                'requireCaseDiff'         => true,
                'requireNumbers'          => true,
                'requireSpecialCharacter' => true,
            ]
        );

        $errors = $this->validator->validate(
            $plainPassword,
            $passwordConstraint
        );

        if (count($errors) > 0) {
            $messages = [];

            foreach ($errors as $error) {
                $messages[] = $error->getMessage();
            }

            throw new InvalidArgumentException(implode("\n", $messages));
        }

        return $plainPassword;
    }

    public function validateNotEmpty(?string $value): string
    {
        if (empty($value)) {
            throw new InvalidArgumentException($this->translator->trans('addUser.error.notEmpty'));
        }

        return $value;
    }
}
